Service

Struct Service 

pub struct Service<Req, Resp>
where Req: Payload, Resp: Payload,
{ /* private fields */ }
Request/response service with two paired event services for wakeup.

Implementations

Source

impl<Req, Resp> Service<Req, Resp>
where Req: Payload, Resp: Payload,

pub fn open_or_create( node: &Node<Service>, topic: &str, ) -> Result<Arc<Self>, ExecutorError>

Open or create the service by name, creating the two paired event services.

pub fn server(self: &Arc<Self>) -> Result<Server<Req, Resp>, ExecutorError>

Create a new Server that listens for requests on this service.

pub fn client(self: &Arc<Self>) -> Result<Client<Req, Resp>, ExecutorError>

Create a new Client that sends requests on this service.